@@ -3,7 +3,7 @@
 #
 # Copyright 2005 Lars Wirzenius (liw@iki.fi)
 # Copyright 2011 Mika Pflüger (debian@mikapflueger.de)
-# Copyright © 2012-2013 Andreas Beckmann (anbe@debian.org)
+# Copyright © 2012-2017 Andreas Beckmann (anbe@debian.org)
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -174,7 +174,7 @@ def bts_update_found(bugnr, newversion):
 
 
 def mark_logs_with_reported_bugs():
-    for failed_log in find_logs("fail"):
+    for failed_log in find_logs("fail") + find_logs("untestable"):
         try:
             pname = package_name(failed_log)
             pversion = package_source_version(failed_log)
@@ -222,6 +222,8 @@ def mark_logs_with_reported_bugs():
                                     break
             if not moved:
                 write_bug_file(failed_log, abugs + bugs)
+        except KeyboardInterrupt:
+            raise
         except:
             print('ERROR processing %s' % failed_log)
             print sys.exc_info()[0]
