@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright 2005 Lars Wirzenius (liw@iki.fi)
-# Copyright © 2011-2015 Andreas Beckmann (anbe@debian.org)
+# Copyright © 2011-2017 Andreas Beckmann (anbe@debian.org)
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -36,6 +36,7 @@ import fcntl
 import random
 import ConfigParser
 import apt_pkg
+import pipes
 
 import piupartslib.conf
 import piupartslib.packagesdb
@@ -758,7 +759,7 @@ class Section:
             ret, f = run_test_with_timeout(command, MAX_WAIT_TEST_RUN)
             if not f or f[-1] != '\n':
                 f += '\n'
-            output.write(f)
+            output.write(f.replace('\033', '[ESC]'))
             lastline = f.split('\n')[-2]
             if ret < 0:
                 output.write(" *** Process KILLED - exceed maximum run time ***\n")
@@ -783,7 +784,7 @@ def log_name(package, version):
 
 
 def quote_spaces(vlist):
-    return ["'%s'" % x if ' ' in x else x for x in vlist]
+    return [pipes.quote(x) for x in vlist]
 
 
 def run_test_with_timeout(cmd, maxwait, kill_all=True):
